tlslite.integration.IMAP4_TLS

Package tlslite :: Package integration :: Module IMAP4_TLS |
[show private | hide private]
[frames | no frames]

## Module tlslite.integration.IMAP4_TLS

TLS Lite + imaplib.

Classes
`IMAP4_TLS` | This class extends `imaplib.IMAP4` with TLS support.

Variable Summary
`int` | `IMAP4_TLS_PORT` = 993

Variable Details

    ### IMAP4_TLS_PORT Type: `int` Value:
        993

Generated by Epydoc 2.0 on Mon Feb 21 21:56:54 2005 | http://epydoc.sf.net